@@ -31,7 +31,20 @@ case "$1" in
 	echo freebsd
 	exit 0
 	;;
+    # Remove version number for NetBSD ELF targets
+    netbsdelf* | netbsd1.6* | netbsd2*)
+	echo netbsdelf
+	exit 0
+	;;
     # Remove version number for Darwin
+    darwin7*)
+        echo darwin7
+        exit 0
+        ;;
+    darwin6*)
+        echo darwin6
+        exit 0
+        ;;
     darwin5*)
         echo darwin5
         exit 0
